<?php
/**

* 2007-2015 PrestaShop

*

* NOTICE OF LICENSE

*

* This source file is subject to the Academic Free License (AFL 3.0)

* that is bundled with this package in the file LICENSE.txt.

* It is also available through the world-wide-web at this URL:

* http://opensource.org/licenses/afl-3.0.php

* If you did not receive a copy of the license and are unable to

* obtain it through the world-wide-web, please send an email

* to license@prestashop.com so we can send you a copy immediately.

*

* DISCLAIMER

*

* Do not edit or add to this file if you wish to upgrade PrestaShop to newer

* versions in the future. If you wish to customize PrestaShop for your

* needs please refer to http://www.prestashop.com for more information.

*

*  @author PrestaShop SA <contact@prestashop.com>

*  @copyright  2007-2015 PrestaShop SA

*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)

*  International Registered Trademark & Property of PrestaShop SA

*/

include_once(_PS_MODULE_DIR_.'/payway/payway.php');

include_once(_PS_MODULE_DIR_.'/payway/api/PayWayApi.php');



/**

 * @since 1.5.0

 */

class PaywayPaymentModuleFrontController extends ModuleFrontController
{
    public $ssl = true;



    public function __construct()
    {
        parent::__construct();
    }



    public function init()
    {
        parent::init();
    }



    public function initContent()
    {
        parent::initContent();

        if (Tools::getIsset('create-pending-order')) {
            $this->createPendingOrder();
        }
    }



    public function setMedia()
    {
        parent::setMedia();
    }



    public function process()
    {
        parent::process();
    }



    public function displayContent()
    {
        parent::displayContent();

        $this->context->smarty->clearAllCache();

        if ($this->context->cart->id) {
            $this->context->smarty->display(_PS_MODULE_DIR_ . 'payway/views/templates/front/payment.tpl');

            return;
        }



        $this->context->smarty->display(_PS_MODULE_DIR_ . 'payway/views/templates/front/empty.tpl');
    }



    public function createPendingOrder()
    {
        $payWay = new PayWay();

        $context = $this->context;

        $cart = $context->cart;

        if ($cart->id_customer == 0 || $cart->id_address_delivery == 0 || $cart->id_address_invoice == 0 || !$payWay->active) {
            Tools::redirect('index.php?controller=order&step=1');
        }



        // Check that this payment option is still available in case the customer changed his address just

        // before the end of the checkout process

        $authorized = false;

        foreach (Module::getPaymentModules() as $module) {
            if ($module['name'] == 'payway') {
                $authorized = true;

                break;
            }
        }



        if (!$authorized) {
            die($payWay->getTranslator()->trans('This payment method is not available.', array(), 'Modules.PayWay.Shop'));
        }



        $customer = new Customer((int) $cart->id_customer);

        if (!Validate::isLoadedObject($customer)) {
            Tools::redirect('index.php?controller=order&step=1');
        }

        

        $cartId = (int)$cart->id;

        $total = (float)$cart->getOrderTotal();

        $shippingCost = (float)$cart->getTotalShippingCost();

        $items = $cart->getProducts(true);

        $item_data = array();

        $i = 0;

        foreach ($items as $item) {
            $item_data[$i]['name'] = $item['name'];

            $item_data[$i]['quantity'] = $item['quantity'];

            $item_data[$i]['price'] = sprintf("%.2f", $item['price']);

            $i++;
        }

        $items_data = base64_encode(json_encode($item_data));



        try {
            $payWay->validateOrder(
                $cartId,
                (int)Configuration::get('ABA_PAYWAY_WAITING_PAYMENT'),
                $total,
                $payWay->displayName,
                null,
                array(),
                null,
                false,
                $this->context->cart->secure_key
            );
        } catch (Exception $e) {
            http_response_code(400);

            exit;
        }

        $id_order = $payWay->currentOrder;

        die(json_encode(array(

            'id_order' => $id_order,

            // 'hash' => PayWayApi::getHash($id_order, $total, $items_data, $shippingCost),
            'hash' => PayWayApi::getHash($id_order, $total, $items_data),

            'items' => $items_data,

            'shippingCost' => $shippingCost,

            'return_url' => PayWayApi::getPushUrl(),

            'redirect_url' => PayWayApi::getRedirectUrl([

                'id_order' => $id_order,

                'id_cart' => $cartId,

                'key' => $customer->secure_key,

                'id_module' => $payWay->id,

            ]),

            'cancel_url' => PayWayApi::getCancelUrl([

                'id_order' => $id_order,

                'id_cart' => $cartId,

                'key' => $customer->secure_key,

                'id_module' => $payWay->id,

            ]),

        )));
    }
}
