<?php
/**
@author ABA Bank Developer
@copyright payway.com.kh 2019
@license ABA Bank License version 1
*/

/**
 * Short description for file
 *
 * Long description for file (if any)...
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.01 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_01.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   CategoryName
 * @package    PackageName
 * @author     Original Author <author@example.com>
 * @author     Another Author <another@example.com>
 * @copyright  1997-2005 The PHP Group
 * @license    http://www.php.net/license/3_01.txt  PHP License 3.01
 * @version    SVN: $Id$
 * @link       http://pear.php.net/package/PackageName
 * @see        NetOther, Net_Sample::Net_Sample()
 * @since      File available since Release 1.2.0
 * @deprecated File deprecated in Release 2.0.0
 */

/**
 * This is a "Docblock Comment," also known as a "docblock."  The class'
 * docblock, below, contains a complete description of how to write these.
 */

if (!defined('_PS_VERSION_')) {
    exit;
}



include_once(_PS_MODULE_DIR_ . '/payway/api/PayWayApi.php');



class PayWay extends PaymentModule
{
    private $site_url;

    private $return_url;



    public function __construct()
    {
        $this->name = 'payway';

        $this->tab = 'payments_gateways';

        $this->version = '1.3.0';

        $this->author = 'ABA Bank';

        $this->currencies = true;

        $this->currencies_mode = 'checkbox';

        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);

        $this->bootstrap = true;



        parent::__construct();



        $this->description = "Payment Gateway By ABA Bank";

        $this->displayName = $this->l('ABA PayWay Payment Gateway');



        $this->confirmUninstall = $this->l('Are you sure you want to delete your details?');



        $this->site_url = Tools::getShopDomainSsl(true, true) . __PS_BASE_URI__;

        $this->return_url = Tools::getShopDomainSsl(
            true,
            true
        ) . __PS_BASE_URI__ . 'module/' . $this->name . '/pushback';
    }



    public function install()
    {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }



        if (!parent::install()

            || !$this->registerHook('header')

            || !$this->registerHook('payment')

            || !$this->registerHook('paymentReturn')

        ) {
            return false;
        }



        include_once _PS_MODULE_DIR_ . $this->name . '/payway_install.php';

        $payWayInstall = new PayWayInstall();

        $payWayInstall->updateConfiguration();

        $payWayInstall->createOrderState();



        return true;
    }





    public function uninstall()
    {
        include_once _PS_MODULE_DIR_ . $this->name . '/payway_install.php';

        $payWayInstall = new PayWayInstall();

        $payWayInstall->deleteConfiguration();

        return parent::uninstall();
    }



    public function hookDisplayHeader($params)
    {
        $this->hookHeader($params);
    }



    /**

     * Hooks methods

     */

    public function hookHeader($params)
    {
        $this->context->controller->addCSS(($this->_path).'views/css/payway.css', 'all');

        $this->context->controller->addJs($this->_path.'views/js/payway.js');
    }

    public function hookPayment($params)
    {
        if (!$this->active) {
            return;
        }
        $this->smarty->assign(
            $this->getTemplateVars()
        );
        return $this->display(__FILE__, 'views/templates/hook/payment.tpl');
    }

    public function hookPaymentReturn($params)
    {
        if (!$this->active) {
            return;
        }

        $state = $params['objOrder']->getCurrentState();

        if (in_array($state, array(Configuration::get('ABA_PAYWAY_PAYMENT_SUCCESS')))) {
            $this->smarty->assign(array(

                'total_to_pay' => Tools::displayPrice(
                    $params['objOrder']->getOrdersTotalPaid(),
                    new Currency($params['objOrder']->id_currency),
                    false
                ),
                'shop_name' => $this->context->shop->name,
                'status' => 'ok',
                'id_order' => $params['objOrder']->id,
            ));

            if (isset($params['objOrder']->reference) && !empty($params['objOrder']->reference)) {
                $this->smarty->assign('reference', $params['objOrder']->reference);
            }
        } else {
            $this->smarty->assign('status', 'failed');
        }

        return $this->display(__FILE__, 'payment_return.tpl');
    }

    public function getContent()
    {
        $this->_html = '';

        if (Tools::isSubmit('btnSubmit')) {
            $this->postValidation();

            if (!count($this->postErrors)) {
                $this->postProcess();
            } else {
                foreach ($this->postErrors as $err) {
                    $this->_html .= $this->displayError($err);
                }
            }
        }



        $this->_html .= $this->displayPayWay();

        $this->_html .= $this->renderForm();

        return $this->_html;
    }

    private function displayPayWay()
    {
        return $this->display(__FILE__, '../admin/header.tpl');
    }

    public function renderForm()
    {
        $fields_form = array(

            'form' => array(

                'legend' => array(

                    'title' => $this->l('PayWay Setup'),

                    'icon' => 'icon-credit-card',

                ),

                'input' => array(

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Payment Label'),

                        'name' => 'ABA_PAYWAY_FRONTEND_NAME',
                        
                        'required' => true,

                        'desc' => 'Display name on front end.',

                    ),

                    array(

                        'type' => 'select',

                        'label' => $this->l('Sandbox Mode'),

                        'name' => 'ABA_PAYWAY_SANDBOX_MODE',

                        'required' => true,

                        'options' => array(

                            'query' => array(

                                array('key' => '1', 'name' => $this->l('Yes')),

                                array('key' => '0', 'name' => $this->l('No')),

                            ),
                            'id' => 'key',

                            'name' => 'name'
                        )
                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Production API base URL'),

                        'name' => 'ABA_PAYWAY_API_BASE_URL',

                        'required' => true,

                        'desc' => 'API Server Base URL. eg. https://api.example.com/',

                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Sandbox API base URL'),

                        'name' => 'ABA_PAYWAY_API_BASE_URL_SANDBOX',

                        'desc' => 'API Sandbox Server Base URL. eg. https://api.example.com/',

                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Production API Endpoint'),

                        'name' => 'ABA_PAYWAY_API_ENDPOINT',

                        'required' => true,

                        'desc' => 'API URL that is provided by PayWay must be required in your post form. eg. https://api.example.com/api/',

                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Sandbox API Endpoint'),

                        'name' => 'ABA_PAYWAY_API_ENDPOINT_SANDBOX',

                        'required' => false,

                        'desc' => 'API URL that is provided by PayWay must be required in your post form. eg. https://api.example.com/api/',

                    ),

                    array(

                        'type' => 'text',

                        'label' => $this->l('API Key'),

                        'name' => 'ABA_PAYWAY_API_KEY',

                        'required' => true,

                        'desc' => 'API KEY that is generated and provided by PayWay must be required in your post form',

                    ),

                    array(

                        'type' => 'text',

                        'label' => $this->l('Merchant ID'),

                        'name' => 'ABA_PAYWAY_MERCHANT_ID',

                        'required' => true,

                        'desc' => $this->l('Merchant ID that is generated and provided by PayWay must be required in your post form'),

                    ),

                    array(

                        'type' => 'select',

                        'label' => $this->l('Hide/Unhide Close Button'),

                        'name' => 'ABA_PAYWAY_POPUP_HIDE_BTN',

                        'required' => true,

                        'options' => array(

                            'query' => array(

                                array('key' => '0', 'name' => $this->l('No')),
                                array('key' => '1', 'name' => $this->l('Yes')),

                            ),

                            'id' => 'key',

                            'name' => 'name'

                        )

                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Production API CSS URL'),

                        'name' => 'ABA_PAYWAY_API_CSS_URL',

                        'required' => true,

                        'desc' => 'Default: https://payway-staging.ababank.com/checkout-popup.html?file=css',

                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Production API JS URL'),

                        'name' => 'ABA_PAYWAY_API_JS_URL',

                        'required' => true,

                        'desc' => 'Default: https://payway-staging.ababank.com/checkout-popup.html?file=js&custom-js=prestashop16',

                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Sandbox API CSS URL'),

                        'name' => 'ABA_PAYWAY_API_CSS_URL_SANDBOX',

                        'required' => true,

                        'desc' => 'Default: https://payway-staging.ababank.com/checkout-popup.html?file=css',

                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Sandbox API JS URL'),

                        'name' => 'ABA_PAYWAY_API_JS_URL_SANDBOX',

                        'required' => true,

                        'desc' => 'Default: https://payway-staging.ababank.com/checkout-popup.html?file=js&custom-js=prestashop16',

                    ),
/*
array(

'type' => 'text',

'class' => 'sm',

'label' => $this->l('Pushback URL'),

'name' => 'ABA_PAYWAY_API_CALL_BACK_URL',

'required' => true,

'desc' => 'Push back notification URL for update order process. Default: ' . $this->return_url,

),
*/
                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Continue Success URL for Web'),

                        'name' => 'ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_WEB',

                        'desc' => 'The URL Host has to be registered in Merchant profile. Otherwise, PayWay will reject the request.

                        Default: ' . $this->site_url,

                    ),

                    array(

                        'type' => 'text',

                        'class' => 'sm',

                        'label' => $this->l('Continue Success URL for Mobile'),

                        'name' => 'ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_MOBILE',

                        'desc' => 'The URL Host has to be registered in Merchant profile. Otherwise, PayWay will reject the request.

                        Default: ' . $this->site_url,

                    ),

                    array(

                        'type' => 'select',

                        'label' => $this->l('Payment Logos'),

                        'name' => 'payment_options[]',

                        'required' => true,

                        'multiple' => true,

                        'options' => array(

                            'query' => array(

                                array('key' => 'aba', 'name' => $this->l('ABA PAY')),

                                array('key' => 'credit_debit', 'name' => $this->l('Credit/Debit Card')),

                            ),

                            'id' => 'key',

                            'name' => 'name'

                        )

                    ),

                    array(

                        'type' => 'select',

                        'label' => $this->l('Logo Size'),

                        'name' => 'ABA_PAYWAY_LOGO_IMAGE_SIZE',

                        'required' => true,

                        'options' => array(

                            'query' => array(

                                array('key' => '1x', 'name' => $this->l('1x')),

                                array('key' => '2x', 'name' => $this->l('2x')),

                                array('key' => '3x', 'name' => $this->l('3x')),

                            ),

                            'id' => 'key',

                            'name' => 'name'

                        )

                    ),
                    
                    array(

                        'type' => 'select',

                        'label' => $this->l('Background Color'),

                        'name' => 'ABA_PAYWAY_BG_COLOR',

                        'required' => true,

                        'options' => array(

                            'query' => array(

                                array('key' => 'white', 'name' => $this->l('White Background')),

                                array('key' => 'colorful', 'name' => $this->l('Color Background')),

                            ),

                            'id' => 'key',

                            'name' => 'name'

                        )

                    ),

                ),

                'submit' => array(

                    'title' => $this->l('Save'),

                ),

            ),

        );



        $helper = new HelperForm();

        $helper->show_toolbar = false;

        $helper->table = $this->table;

        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));

        $helper->default_form_language = $lang->id;

        $value1 = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG');

        $value2 = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG');

        $helper->allow_employee_form_lang = $value1 ? $value2 : 0;

        $this->fields_form = array();

        $helper->id = (int)Tools::getValue('id_carrier');

        $helper->identifier = $this->identifier;

        $helper->submit_action = 'btnSubmit';

        $value3 = '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name;

        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false) . $value3;

        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(

            'fields_value' => $this->getConfigFieldsValues(),

            'languages' => $this->context->controller->getLanguages(),

            'id_language' => $this->context->language->id,

        );



        return $helper->generateForm(array($fields_form));
    }



    private function postValidation()
    {
        if (Tools::isSubmit('btnSubmit')) {
            if (!Tools::getValue('ABA_PAYWAY_API_BASE_URL')) {
                $this->postErrors[] = $this->l('You must enter "ABA PayWay API Base URL"');
            }



            if (!Tools::getValue('ABA_PAYWAY_API_ENDPOINT')) {
                $this->postErrors[] = $this->l('You must enter "ABA PayWay API ENDPOINT"');
            }



            if (!Tools::getValue('ABA_PAYWAY_API_KEY')) {
                $this->postErrors[] = $this->l('You must enter "ABA PayWay API KEY"');
            }



            if (!Tools::getValue('ABA_PAYWAY_MERCHANT_ID')) {
                $this->postErrors[] = $this->l('You must enter your "ABA PayWay Merchant ID"');
            }


/*
if (!Tools::getValue('ABA_PAYWAY_API_CALL_BACK_URL')) {
$this->postErrors[] = $this->l('You must enter "ABA PayWay Call Back URL"');
}
*/


            if (!Tools::getValue('ABA_PAYWAY_API_CSS_URL')) {
                $this->postErrors[] = $this->l('You must enter "ABA PayWay API CSS URL"');
            }



            if (!Tools::getValue('ABA_PAYWAY_API_JS_URL')) {
                $this->postErrors[] = $this->l('You must enter "ABA PayWay API JS URL"');
            }



            if (!Tools::getValue('ABA_PAYWAY_API_CSS_URL_SANDBOX')) {
                $this->postErrors[] = $this->l('You must enter "ABA PayWay API Sandbox CSS URL"');
            }



            if (!Tools::getValue('ABA_PAYWAY_API_JS_URL_SANDBOX')) {
                $this->postErrors[] = $this->l('You must enter "ABA PayWay API Sandbox JS URL"');
            }
        }
    }



    private function postProcess()
    {
        if (Tools::isSubmit('btnSubmit')) {
            Configuration::updateValue('ABA_PAYWAY_FRONTEND_NAME', Tools::getValue('ABA_PAYWAY_FRONTEND_NAME'));

            Configuration::updateValue('ABA_PAYWAY_SANDBOX_MODE', Tools::getValue('ABA_PAYWAY_SANDBOX_MODE'));

            Configuration::updateValue('ABA_PAYWAY_API_BASE_URL', Tools::getValue('ABA_PAYWAY_API_BASE_URL'));

            Configuration::updateValue('ABA_PAYWAY_API_BASE_URL_SANDBOX', Tools::getValue('ABA_PAYWAY_API_BASE_URL_SANDBOX'));

            Configuration::updateValue('ABA_PAYWAY_API_ENDPOINT', Tools::getValue('ABA_PAYWAY_API_ENDPOINT'));

            Configuration::updateValue('ABA_PAYWAY_API_ENDPOINT_SANDBOX', Tools::getValue('ABA_PAYWAY_API_ENDPOINT_SANDBOX'));

            Configuration::updateValue('ABA_PAYWAY_API_KEY', Tools::getValue('ABA_PAYWAY_API_KEY'));

            Configuration::updateValue('ABA_PAYWAY_MERCHANT_ID', Tools::getValue('ABA_PAYWAY_MERCHANT_ID'));

            Configuration::updateValue('ABA_PAYWAY_POPUP_HIDE_BTN', Tools::getValue('ABA_PAYWAY_POPUP_HIDE_BTN'));

            Configuration::updateValue('ABA_PAYWAY_API_CSS_URL', Tools::getValue('ABA_PAYWAY_API_CSS_URL'));

            Configuration::updateValue('ABA_PAYWAY_API_JS_URL', Tools::getValue('ABA_PAYWAY_API_JS_URL'));

            Configuration::updateValue('ABA_PAYWAY_API_CSS_URL_SANDBOX', Tools::getValue('ABA_PAYWAY_API_CSS_URL_SANDBOX'));

            Configuration::updateValue('ABA_PAYWAY_API_JS_URL_SANDBOX', Tools::getValue('ABA_PAYWAY_API_JS_URL_SANDBOX'));
/*
Configuration::updateValue('ABA_PAYWAY_API_CALL_BACK_URL', Tools::getValue('ABA_PAYWAY_API_CALL_BACK_URL'));
*/
            Configuration::updateValue(
                'ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_WEB',
                Tools::getValue('ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_WEB')
            );

            Configuration::updateValue(
                'ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_MOBILE',
                Tools::getValue('ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_MOBILE')
            );

            Configuration::updateValue(
                'ABA_PAYWAY_PAYMENT_OPTIONS',
                serialize(Tools::getValue('payment_options'))
            );

            Configuration::updateValue(
                'ABA_PAYWAY_LOGO_IMAGE_SIZE',
                Tools::getValue('ABA_PAYWAY_LOGO_IMAGE_SIZE')
            );
                
            Configuration::updateValue(
                'ABA_PAYWAY_BG_COLOR',
                Tools::getValue('ABA_PAYWAY_BG_COLOR')
            );
        }

        $this->_html .= $this->displayConfirmation($this->l('Settings updated'));
    }



    public function getConfigFieldsValues()
    {
        $frontendName = Tools::getValue('ABA_PAYWAY_FRONTEND_NAME', Configuration::get('ABA_PAYWAY_FRONTEND_NAME'));

        $sandbox = Tools::getValue('ABA_PAYWAY_SANDBOX_MODE', Configuration::get('ABA_PAYWAY_SANDBOX_MODE'));

        $baseUrl = Tools::getValue('ABA_PAYWAY_API_BASE_URL', Configuration::get('ABA_PAYWAY_API_BASE_URL'));

        $baseUrlSandbox = Tools::getValue('ABA_PAYWAY_API_BASE_URL_SANDBOX', Configuration::get('ABA_PAYWAY_API_BASE_URL_SANDBOX'));

        $endPoint = Tools::getValue('ABA_PAYWAY_API_ENDPOINT', Configuration::get('ABA_PAYWAY_API_ENDPOINT'));

        $endPointSandbox = Tools::getValue('ABA_PAYWAY_API_ENDPOINT_SANDBOX', Configuration::get('ABA_PAYWAY_API_ENDPOINT_SANDBOX'));

        $apiKey = Tools::getValue('ABA_PAYWAY_API_KEY', Configuration::get('ABA_PAYWAY_API_KEY'));

        $merchantId = Tools::getValue('ABA_PAYWAY_MERCHANT_ID', Configuration::get('ABA_PAYWAY_MERCHANT_ID'));

        $hideBtn = Tools::getValue('ABA_PAYWAY_POPUP_HIDE_BTN', Configuration::get('ABA_PAYWAY_POPUP_HIDE_BTN'));

        $cssUrl = Tools::getValue('ABA_PAYWAY_API_CSS_URL', Configuration::get('ABA_PAYWAY_API_CSS_URL'));

        if (!$cssUrl) {
            $cssUrl = 'https://payway-staging.ababank.com/checkout-popup.html?file=css';
        }

        $jsUrl = Tools::getValue('ABA_PAYWAY_API_JS_URL', Configuration::get('ABA_PAYWAY_API_JS_URL'));

        if (!$jsUrl) {
            $jsUrl = 'https://payway-staging.ababank.com/checkout-popup.html?file=js&custom-js=prestashop16';
        }

        $cssUrlSandbox = Tools::getValue('ABA_PAYWAY_API_CSS_URL_SANDBOX', Configuration::get('ABA_PAYWAY_API_CSS_URL_SANDBOX'));

        if (!$cssUrlSandbox) {
            $cssUrlSandbox = 'https://payway-staging.ababank.com/checkout-popup.html?file=css';
        }

        $jsUrlSandbox = Tools::getValue('ABA_PAYWAY_API_JS_URL_SANDBOX', Configuration::get('ABA_PAYWAY_API_JS_URL_SANDBOX'));

        if (!$jsUrlSandbox) {
            $jsUrlSandbox = 'https://payway-staging.ababank.com/checkout-popup.html?file=js&custom-js=prestashop16';
        }
/*
$callBackDefaultValue = Configuration::get('ABA_PAYWAY_API_CALL_BACK_URL');

if (empty($callBackDefaultValue)) {
$callBackDefaultValue = $this->return_url;
}

$callBack = Tools::getValue('ABA_PAYWAY_API_CALL_BACK_URL', $callBackDefaultValue);
*/
        $callBack = $this->return_url;

        $redirectWeb = Tools::getValue(
            'ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_WEB',
            Configuration::get('ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_WEB')
        );

        $redirectMobile = Tools::getValue(
            'ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_MOBILE',
            Configuration::get('ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_MOBILE')
        );

        $paymentOptions = unserialize(Configuration::get('ABA_PAYWAY_PAYMENT_OPTIONS'));

        if ($paymentOptions === false && $paymentOptions != 'b:0;') {
            $paymentOptions = array();
        }

        $paymentOptions = Tools::getValue(
            'payment_options[]',
            $paymentOptions
        );

        $imageSize = Tools::getValue(
            'ABA_PAYWAY_LOGO_IMAGE_SIZE',
            Configuration::get('ABA_PAYWAY_LOGO_IMAGE_SIZE')
        );
            
        $bgColor = Tools::getValue(
            'ABA_PAYWAY_BG_COLOR',
            Configuration::get('ABA_PAYWAY_BG_COLOR')
        );



        return array(

            'ABA_PAYWAY_FRONTEND_NAME' => $frontendName,

            'ABA_PAYWAY_SANDBOX_MODE' => $sandbox,

            'ABA_PAYWAY_API_BASE_URL' => $baseUrl,

            'ABA_PAYWAY_API_BASE_URL_SANDBOX' => $baseUrlSandbox,

            'ABA_PAYWAY_API_ENDPOINT' => $endPoint,

            'ABA_PAYWAY_API_ENDPOINT_SANDBOX' => $endPointSandbox,

            'ABA_PAYWAY_API_KEY' => $apiKey,
            'ABA_PAYWAY_MERCHANT_ID' => $merchantId,
			'ABA_PAYWAY_API_CALL_BACK_URL' => $callBack,
            'ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_WEB' => $redirectWeb,

            'ABA_PAYWAY_SUCCESSFUL_REDIRECTION_URL_MOBILE' => $redirectMobile,

            'payment_options[]' => $paymentOptions,

            'ABA_PAYWAY_LOGO_IMAGE_SIZE' => $imageSize,
            
            'ABA_PAYWAY_BG_COLOR' => $bgColor,

            'ABA_PAYWAY_POPUP_HIDE_BTN' => $hideBtn,

            'ABA_PAYWAY_API_CSS_URL' => $cssUrl,

            'ABA_PAYWAY_API_JS_URL' => $jsUrl,

            'ABA_PAYWAY_API_CSS_URL_SANDBOX' => $cssUrlSandbox,

            'ABA_PAYWAY_API_JS_URL_SANDBOX' => $jsUrlSandbox,

        );
    }



    public function checkCurrency($cart)
    {
        $currency_order = new Currency((int)($cart->id_currency));

        $currencies_module = $this->getCurrency((int)$cart->id_currency);



        if (is_array($currencies_module)) {
            foreach ($currencies_module as $currency_module) {
                if ($currency_order->id == $currency_module['id_currency']) {
                    return true;
                }
            }
        }

        return false;
    }



    public function getTemplateVars()
    {
        $customer = $this->context->customer;

        $billing_address = new Address($this->context->cart->id_address_invoice);

        $cart = $this->context->cart;

        $cart_id = (int)$cart->id;

        $total = (float)$cart->getOrderTotal();

        $shippingCost = (float)$cart->getTotalShippingCost();

        $items = $cart->getProducts(true);

        $item_data = array();

        $i = 0;

        foreach ($items as $item) {
            $item_data[$i]['name'] = $item['name'];

            $item_data[$i]['quantity'] = $item['quantity'];

            $item_data[$i]['price'] = $item['price'];

                        

            $i++;
        }

        $items_data = base64_encode(json_encode($item_data));

        $merchantId = Tools::safeOutput(Configuration::get('ABA_PAYWAY_MERCHANT_ID'));

        $transactionId = $cart_id;

        $skey = $cart->secure_key;

        $name_site = "Order # ";

        $images = unserialize(Configuration::get('ABA_PAYWAY_PAYMENT_OPTIONS'));

        if ($images === false && $images != 'b:0;') {
            $images = array();
        }

        $frontendName = Tools::getValue('ABA_PAYWAY_FRONTEND_NAME', Configuration::get('ABA_PAYWAY_FRONTEND_NAME'));

        $imageSize = '1x';

        if (Configuration::get('ABA_PAYWAY_LOGO_IMAGE_SIZE')) {
            $imageSize = Configuration::get('ABA_PAYWAY_LOGO_IMAGE_SIZE');
        }
        
        $bgColor = 'white';

        if (Configuration::get('ABA_PAYWAY_BG_COLOR')) {
            $bgColor = Configuration::get('ABA_PAYWAY_BG_COLOR');
        }



        $hide_btn_arg = '';

        if (Configuration::get('ABA_PAYWAY_POPUP_HIDE_BTN')) {
            $hide_btn_arg = '&hide-close=1';
        }

        return [

            'this_path' => $this->_path,

            'base_url' => PayWayApi::getBaseUrl(),

            'end_point' => PayWayApi::getEndPoint(),

            'return_url' => PayWayApi::getPushUrl(),

            'redirect_url' => PayWayApi::getRedirectUrl(),

            'cancel_url' => PayWayApi::getCancelUrl(),

            'merchantId' => $merchantId,

            'name' => $name_site,

            'skey' => $skey,

            'cart_id' => $cart_id,

            'total' => $total,

            'shippingCost' => $shippingCost,

            // 'hash' => PayWayApi::getHash($transactionId, $total, $items_data, $shippingCost),
            'hash' => PayWayApi::getHash($transactionId, $total, $items_data),

            'items' => $items_data,

            'tran_id' => $transactionId,

            'firstname' => $customer->firstname,

            'lastname' => $customer->lastname,

            'email' => $customer->email,

            'phone' => $billing_address->phone,

            'images' => $images,

            'frontendName' => $frontendName,

            'image_size' => $imageSize,
            
            'bg_color' => $bgColor,

            'base_sslurl' => Tools::getShopDomainSsl(true, true) . __PS_BASE_URI__,

            'hide_btn_arg' => $hide_btn_arg,

            'css_url' => PayWayApi::getCssUrl(),

            'js_url' => PayWayApi::getJsUrl(),

        ];
    }
}
